/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.util.HashMap;
import java.util.Map;

import org.json.JSONObject;

/**
 * @author Michael Hashimoto
 */
public class BaseCommit implements Commit {

	public BaseCommit(String message, String sha) {
		this(message, sha, null);
	}

	public BaseCommit(String message, String sha, Type type) {
		_message = message;
		_sha = sha;
		_type = type;
	}

	@Override
	public boolean equals(Object object) {
		if (object.hashCode() == hashCode()) {
			return true;
		}

		return false;
	}

	@Override
	public String getAbbreviatedSHA() {
		return _sha.substring(0, 7);
	}

	@Override
	public String getMessage() {
		return _message;
	}

	@Override
	public String getSHA() {
		return _sha;
	}

	@Override
	public Type getType() {
		return _type;
	}

	@Override
	public int hashCode() {
		JSONObject jsonObject = _toJSONObject();

		String json = jsonObject.toString();

		return json.hashCode();
	}

	private JSONObject _toJSONObject() {
		JSONObject jsonObject = new JSONObject();

		jsonObject.put("message", _message);
		jsonObject.put("sha", _sha);

		return jsonObject;
	}

	private static final Map<String, Integer> _map = new HashMap<>();

	private final String _message;
	private final String _sha;
	private final Type _type;

}